//+------------------------------------------------------------------+
//|                                                 Weekly Pivot.mq4 |
//|                                                         value808 |
//|                                                            v.0.2 |
//+------------------------------------------------------------------+
#property copyright "value808"
#property link      ""

#property indicator_chart_window
#property indicator_buffers 3
#property indicator_color1 MediumBlue
#property indicator_color2 MediumBlue
#property indicator_color3 MediumBlue

double ExtMapBuffer1[];
double ExtMapBuffer2[];
double ExtMapBuffer3[];

//---- input parameters
extern int       Pivot.1.Calculation.Method = PRICE_TYPICAL; // Corresponds to the "Applied price constants" mapping (see manual for details).
extern int       Pivot.2.Calculation.Method = PRICE_HIGH;
extern int       Pivot.3.Calculation.Method = PRICE_LOW;
extern bool      Show.Pivot.2 = false;
extern bool      Show.Pivot.3 = false;
extern bool      Use.Lines = false;
extern int       Arrow.Code = 158;
extern int       Bars.To.Count = 500;

bool active = true;
double pivotPrice = EMPTY_VALUE, pivotPrice2 = EMPTY_VALUE, pivotPrice3 = EMPTY_VALUE;

int chartPeriod;
int lastDay = 0;
	

//+------------------------------------------------------------------+
//| Custom indicator initialization function                         |
//+------------------------------------------------------------------+
int init()
  {
  
   chartPeriod = Period();
	  
   if (chartPeriod>PERIOD_D1) {
      Alert("Not suitable for periods higher than D1!");
      active = false;
   }
   
   int indicatorType = 0;
   if (Use.Lines) indicatorType = DRAW_LINE; else indicatorType = DRAW_ARROW;
   
   SetIndexStyle(0,indicatorType,EMPTY,1);
   SetIndexArrow(0,Arrow.Code);
   SetIndexBuffer(0,ExtMapBuffer1);

   SetIndexStyle(1,indicatorType,EMPTY,1);
   SetIndexArrow(1,Arrow.Code);
   SetIndexBuffer(1,ExtMapBuffer2);

   SetIndexStyle(2,indicatorType,EMPTY,1);
   SetIndexArrow(2,Arrow.Code);
   SetIndexBuffer(2,ExtMapBuffer3);
   
   return(0);
  }
  
//+------------------------------------------------------------------+
//| Custom indicator deinitialization function                       |
//+------------------------------------------------------------------+
int deinit()
  {
//----
   
//----
   return(0);
  }
//+------------------------------------------------------------------+
//| Custom indicator iteration function                              |
//+------------------------------------------------------------------+
int start()
  {
   if (!active) return (1);
	int counted_bars = IndicatorCounted();
	if (counted_bars<0)  { return (-1); }

   int limit = Bars - counted_bars - 1;	

   if (Bars.To.Count != 0 && limit > Bars.To.Count) limit = Bars.To.Count;

	for (int i=limit; i>=0; i--) {
	  
	  datetime timeBar = 0;
	  if (i == 0) {
	     timeBar = CurTime();
	  } else {
	     timeBar = iTime(NULL,0,i);
	  }
	  
	  int curDay = TimeDayOfWeek(timeBar);
	  if (curDay < lastDay) {
	     
	     datetime openTime = timeBar - PERIOD_W1*60;
	     
	     int barShiftOpen = iBarShift(NULL,0,openTime,false);
	     int barShiftClose = i+1;
	     int periods = barShiftOpen - barShiftClose;
	     
	     double openPrice = iOpen(NULL,0,barShiftOpen);
	     double closePrice = iClose(NULL,0,barShiftClose);
	     double highPrice = iHigh(NULL,0,Highest(NULL,0,MODE_HIGH,periods,barShiftClose));
	     double lowPrice = iLow(NULL,0,Lowest(NULL,0,MODE_LOW,periods,barShiftClose));
	     
        switch (Pivot.1.Calculation.Method) {
            case PRICE_CLOSE:    pivotPrice = closePrice; break;
            case PRICE_OPEN:     pivotPrice = openPrice; break;
            case PRICE_HIGH:     pivotPrice = highPrice; break;
            case PRICE_LOW:      pivotPrice = lowPrice; break;
            case PRICE_MEDIAN:   pivotPrice = (highPrice+lowPrice)/2; break;
            case PRICE_TYPICAL:  pivotPrice = (highPrice+lowPrice+closePrice)/3; break;
            case PRICE_WEIGHTED: pivotPrice = (highPrice+lowPrice+2*closePrice)/4; break;
        }

        switch (Pivot.2.Calculation.Method) {
            case PRICE_CLOSE:    pivotPrice2 = closePrice; break;
            case PRICE_OPEN:     pivotPrice2 = openPrice; break;
            case PRICE_HIGH:     pivotPrice2 = highPrice; break;
            case PRICE_LOW:      pivotPrice2 = lowPrice; break;
            case PRICE_MEDIAN:   pivotPrice2 = (highPrice+lowPrice)/2; break;
            case PRICE_TYPICAL:  pivotPrice2 = (highPrice+lowPrice+closePrice)/3; break;
            case PRICE_WEIGHTED: pivotPrice2 = (highPrice+lowPrice+2*closePrice)/4; break;
        }

        switch (Pivot.3.Calculation.Method) {
            case PRICE_CLOSE:    pivotPrice3 = closePrice; break;
            case PRICE_OPEN:     pivotPrice3 = openPrice; break;
            case PRICE_HIGH:     pivotPrice3 = highPrice; break;
            case PRICE_LOW:      pivotPrice3 = lowPrice; break;
            case PRICE_MEDIAN:   pivotPrice3 = (highPrice+lowPrice)/2; break;
            case PRICE_TYPICAL:  pivotPrice3 = (highPrice+lowPrice+closePrice)/3; break;
            case PRICE_WEIGHTED: pivotPrice3 = (highPrice+lowPrice+2*closePrice)/4; break;
        }
        
	  }
	  
	  lastDay = curDay;

     ExtMapBuffer1[i] = pivotPrice;
     if (Show.Pivot.2) ExtMapBuffer2[i] = pivotPrice2;
     if (Show.Pivot.3) ExtMapBuffer3[i] = pivotPrice3;
        
      
	}

   return(0);
  }
//+------------------------------------------------------------------+